@@ -19,13 +19,13 @@ class CommandStatusTracker:
         self.wish_saver = wish_saver or (lambda _: None)
         self.all_completed = False
 
-    def check_status(self, wish: Wish) -> None:
+    async def check_status(self, wish: Wish) -> None:
         """Check the status of running commands.
 
         Args:
             wish: The wish to check the status for.
         """
-        self.executor.check_running_commands()
+        await self.executor.check_running_commands()
 
     def is_all_completed(self, wish: Wish) -> tuple[bool, bool]:
         """Check if all commands have completed.
@@ -40,10 +40,13 @@ class CommandStatusTracker:
         any_failed = False
 
         for result in wish.command_results:
+            # Check if the command is still running
             if result.state == CommandState.DOING:
                 all_completed = False
                 break
-            if result.state != CommandState.SUCCESS:
+            # Check if the command failed
+            # Note: state might be None if it's waiting for wish-log-analysis to set it
+            if result.state is not None and result.state != CommandState.SUCCESS:
                 any_failed = True
 
         return all_completed, any_failed
